==> moodle-1.4.3.tgz: moodle/lang/th/wiki.php <==
<?PHP // $Id$ 
      // wiki.php - created with Moodle 1.5 unstable development (2004083000)


$string['action'] = 'ͧ÷..';
$string['administration'] = 'èѴк';
$string['allowremovepages'] = 'ź˹';
$string['allowrevertchanges'] = 'Ѻǹӡ¹ŧ繤';
$string['allowsetpage'] = '˹';
$string['allowstrippages'] = '˹';
$string['attachments'] = '˹ҷṺ';
$string['author'] = '/¹';
$string['authorfieldpattern'] = 'ٻẺͧͧ¹';
$string['authorfieldpatternerror'] = 'سͼ¹';
$string['backlinks'] = 'ԧҧԧ';
$string['binimgtoolarge'] = 'Ҿ˭Թ令';
$string['binnoimg'] = 'öٻẺ';
$string['browse'] = 'Browse';
$string['canceledit'] = '¡ԡ';
$string['cannotchangepage'] = 'سö¹ŧ˹ҹ';
$string['changes'] = '¹ŧ $a ';
$string['changesfield'] = '㹪ǧҡҡ¹ŧش';
$string['changesfielderror'] = 'سӹǹ١ͧ';
$string['checklinks'] = 'Ǩͺԧ';
$string['checklinkscheck'] = '㨹ФҵͧõǨͺԧ˹ҹ';
$string['checklinksnotice'] = 'ͤس͹Դ֧Фҧ˹ҹѧӧҹ';
$string['chooseadministration'] = 'èѴк';
$string['chooseafile'] = '͡  ѾŴ˹';
$string['choosewikilinks'] = '͡ԧ Wiki';
$string['comment'] = 'Դ';
$string['contentsize'] = 'Ҵͧ';
$string['created'] = 'ҧ';
$string['deletemewikiword'] = 'źѹ';
$string['deletemewikiwordfound'] = ' $a  ˹ҹ';
$string['deletepage'] = 'ź˹ҹ';
$string['deleteversions'] = 'źشѹ';
$string['deleteversionserror'] = 'سŢ١ͧ';
$string['diff'] = 'ᵡҧ';
$string['differences'] = 'ᵡҧҧ  $a->new_ver   $a->old_ver   ͧ $a->pagename.';
$string['disablecamel'] = 'ԧ CamelCase ';
$string['disabledpage'] = '˹ҹѧԡä';
$string['doesnotexist'] = 'ѧաҧ˹ҹ سҤԡ䢶ҡسͧҧѹ';
$string['downloadaszip'] = 'ǹŴ';
$string['downloadtimes'] = 'ǹŴ $a ';
$string['dwnlnofiles'] = 'ѧ辺ѾŴ';
$string['dwnlsection'] = 'ǹѺǹŴ';
$string['editform1'] = 'ͧʹٻẺͧѹҡѡ öѧ';
$string['editform2'] = '¹ѧ˹¹Ф Ң¹ءҧաúѹ֡';
$string['editthispage'] = '˹ҹ';
$string['emptypage'] = '˹';
$string['errorbinandtxt'] = 'բͼԴҴ: ˹ҹ㹻 BIN  TXT';
$string['errorhtml'] = '˹ҹ㹻 HTML';
$string['errornotype'] = 'բͼԴҴ    BIN  TXT';
$string['errororreason'] = 'բͼԴҴ ˵ؼ';
$string['errorroandwr'] = 'բͼԴҴ ˹ҹöҹҹ';
$string['errorsize'] = '˹ҹբҴ˭ 64k';
$string['errversionsave'] = '¤ ҧس˹ҹդ蹷ӡúѹ֡蹢ͧس سҡѺ˹ҷͷӡúѹ֡觷سӡ¹ŧŧ㹤쨡Ŵ˹ҹáͤŧ';
$string['ewikiacceptbinary'] = '͹حҵ亹';
$string['ewikiprinttitle'] = 'Ǣ㹷ء˹Ңͧ Wiki';
$string['export'] = '͡';
$string['exportformats'] = 'ٻẺ͡';
$string['exportsuccessful'] = '͡';
$string['exportto'] = '͡ѧ';
$string['fetchback'] = 'Fetch-back';
$string['file'] = '';
$string['filedownload'] = 'ǹŴ';
$string['fileisoftype'] = '繻';
$string['filtername'] = 'ԧ˹ Wiki ѵѵ';
$string['flagbin'] = 'BIN';
$string['flaghtm'] = 'HTM';
$string['flagoff'] = 'OFF';
$string['flagro'] = 'RO';
$string['flags'] = 'Flags';
$string['flagsset'] = '¹ Flags';
$string['flagtxt'] = 'TXT';
$string['flagwr'] = 'WR';
$string['for'] = 'Ѻ';
$string['forbidden'] = 'سö˹ҹ';
$string['groups'] = '';
$string['hits'] = '$a  ';
$string['howtooperate'] = 'Ըաҹ';
$string['howtowiki'] = 'Ըաҹ wiki';
$string['html'] = 'ٻẺ HTML';
$string['htmlmode'] = ' Html';
$string['htmlonly'] = 'html ҹ';
$string['index'] = 'Ѫ';
$string['infoaboutpage'] = 'ǡѺ˹ҹ';
$string['initialcontent'] = '͡˹á';
$string['invalidroot'] = 'سѺ͹حҵѧ˹شЩй ֧öҧѧ䫵';
$string['lastchanged'] = '¹ŧش $a ';
$string['lastmodified'] = 'ش';
$string['linkdead'] = '';
$string['linkok'] = '';
$string['linkschecked'] = 'Ǩͺԧ';
$string['listall'] = '¡÷';
$string['listcandidates'] = 'List candidates';
$string['meta'] = 'Meta data';
$string['moduledirectory'] = 'ä';
$string['modulename'] = 'Wiki';
$string['modulenameplural'] = 'Wikis';
$string['mostoftenchangedpages'] = '˹ҷ¹·ش';
$string['mostvisitedpages'] = '˹ҷռҪҡش';
$string['newestpages'] = '˹ش';
$string['noadministrationaction'] = 'ѧաèѴ  Ѻк';
$string['nocandidatestoremove'] = 'ѧ˹ҷͧź ͡ \'$a\'  ʴء˹ ';
$string['nochangestorevert'] = 'ա¹ŧѺ';
$string['nohtml'] = ' html';
$string['nolinksfound'] = '辺ԧ˹ҹ';
$string['noregexp'] = 'ҹͧ繤ҵµ ö *  regex Ҩռʧҡ͡ǹк кت port  port number Фҹ鹷ء駷աҼҹҧ http';
$string['notadministratewiki'] = 'سöѴ wiki ';
$string['nothingtostrip'] = '˹ҷҡ˹';
$string['nowikicreated'] = 'բŷҧѺ wiki ';
$string['of'] = 'ͧ';
$string['offline'] = 'ͿŹ';
$string['optional'] = '͡';
$string['orphanedpage'] = 'Orphaned page';
$string['orphanedpages'] = 'Orphaned pages';
$string['otherwikis'] = 'Wiki ';
$string['ownerunknown'] = 'Һ';
$string['pageactions'] = 'Page actions';
$string['pageindex'] = 'úҭͧ˹';
$string['pageinfo'] = 'Ţͧ˹';
$string['pagename'] = '˹';
$string['pagenamechoice'] = '';
$string['pageslinkingto'] = '˹ҷͧԧѧ˹ҹ';
$string['pagesremoved'] = 'ź˹';
$string['pagesreverted'] = '¹Ѻ';
$string['pagesstripped'] = 'ź˹ҹ';
$string['plaintext'] = '˹ѧ͸';
$string['preview'] = 'ٵҧ';
$string['readonly'] = '˹ҹҹҧ ';
$string['refs'] = 'ҧԧ';
$string['removenotice'] = '˵  ˹ҷաҧԧж١ʵ˹ҹ  ewiki ͧͷբͨӡѴöͺ˹ҹ 㹡óշس˹  ˹ ˹Ҵѧǡж١ʵ˹ҹ蹡ѹ';
$string['removepagecheck'] = '㨹Фҵͧź˹Ҵѧ';
$string['removepages'] = '˹';
$string['removeselectedpages'] = '˹ҷ͡';
$string['revertallsince'] = '¹蹡Ѻѧ蹹 ź¹ŧѧҡ';
$string['revertchanges'] = '¹Ѻ';
$string['revertlastonly'] = '¹شҹ';
$string['revertpages'] = '¹  ˹';
$string['revertpagescheck'] = '㨹Фҵͧ¹˹ҵ仹Ѻ';
$string['revertthe'] = '¹Ѻ ź੾˹ҷջѭ';
$string['safehtml'] = 'Safe HTML';
$string['save'] = 'ѹ֡';
$string['searchwiki'] = ' Wiki';
$string['setpageflags'] = '駤 page flags';
$string['sitemap'] = 'ѧ䫵';
$string['smfor'] = 'ѧ䫵Ѻ';
$string['status'] = 'ʶҹ';
$string['strippagecheck'] = 'Ҥзͧź͡ҡ˹ҹ';
$string['strippages'] = 'ź˹͡';
$string['studentadminoptions'] = 'ԷԡèѴ wiki Ѻѡ¹';
$string['submit'] = '';
$string['tabattachments'] = 'Ṻ';
$string['tabedit'] = '';
$string['tabinfo'] = 'History';
$string['tablinks'] = 'ԧ';
$string['tabview'] = '';
$string['thanksforcontribution'] = 'ͺسѺŷسҤ';
$string['thispageisntlinkedfromanywhereelse'] = 'ԧ˹ҹҨҡ';
$string['updatedpages'] = 'Ѿഷ˹ҹ';
$string['uplerror'] = '¤ջѭҧѾŴ';
$string['uplinsect'] = 'ѾŴѧ';
$string['uplnewnam'] = 'ѹ֡㹪';
$string['upload0'] = '㹡ѾŴŧ wiki';
$string['uploadedon'] = 'ѾŴͧ';
$string['uploadpicturebutton'] = 'ѾŴ';
$string['uplok'] = 'ѾŴ١ͧ';
$string['version'] = '';
$string['versionrangetoobig'] = 'سöźء͡ҡ˹ҹ  ش';
$string['versions'] = '';
$string['versionstodelete'] = '蹷ͧź';
$string['viewpage'] = 'ӹǹ˹ҷҪ';
$string['viewsmfor'] = 'Ἱѧ䫵';
$string['wantedpages'] = '˹ҷͧ';
$string['wikidefaultpagename'] = 'Ѫ Wiki';
$string['wikiexport'] = '͡˹ҹ';
$string['wikiexportcomment'] = 'سöӡõ駤ͧ͡ҡ˹ҹ';
$string['wikilinkoptions'] = 'ͧ͡ Wiki ԧѵѵ';
$string['wikilinks'] = 'ԧ Wiki';
$string['wikiname'] = '˹';
$string['wikistartederror'] = 'բ Wiki    ö¹ŧ';
$string['wikitype'] = '';
$string['wikiusage'] = ' wiki';
$string['withbinaries'] = 'úҭ亹';
$string['withvirtualpages'] = 'ԧ wiki';
$string['wrongversionrange'] = '$a  㹪ǧ١ͧ';

?>

==> moodle-1.5.3.tgz: moodle/lang/th/wiki.php <==
<?PHP // $Id$ 
      // wiki.php - created with Moodle 1.4.5 + (2004083150)


$string['action'] = 'ͧ÷..';
$string['administration'] = 'èѴк';
$string['allowremovepages'] = 'ź˹';
$string['allowrevertchanges'] = '¹Ѻ˹Ҿѹ';
$string['allowsetpage'] = '駤ԷԢͧ˹';
$string['allowstrippages'] = 'źѹ';
$string['attachments'] = '˹ҷṺ';
$string['author'] = '/¹';
$string['authorfieldpattern'] = 'ͼ¹';
$string['authorfieldpatternerror'] = 'سͼ¹';
$string['backlinks'] = 'ԧҧԧ';
$string['binimgtoolarge'] = 'ҾբҴ˭ҷк˹';
$string['binnoimg'] = 'ٻẺ١ͧ';
$string['browse'] = 'Browse';
$string['canceledit'] = '¡ԡ';
$string['cannotchangepage'] = 'öӡ¹ŧ';
$string['changes'] = '¹ŧ $a ';
$string['changesfield'] = 'ѧҡ¹ŧش';
$string['changesfielderror'] = 'سӹǹ١ͧ';
$string['checklinks'] = 'Ǩͺԧ';
$string['checklinkscheck'] = '㨹ФҵͧõǨͺԧ˹ҹ';
$string['checklinksnotice'] = 'ѡ˹ҹѧӧҹ';
$string['chooseadministration'] = 'èѴк';
$string['chooseafile'] = '͡ѾŴ˹';
$string['choosewikilinks'] = '͡ԧ Wiki';
$string['comment'] = 'Դ';
$string['contentsize'] = 'Ҵͧ';
$string['created'] = 'ҧ';
$string['deletemewikiword'] = 'ź';
$string['deletemewikiwordfound'] = ' $a ˹ҹ';
$string['deletepage'] = 'ź˹ҹ';
$string['deleteversions'] = 'ӹǹѹشͧź';
$string['deleteversionserror'] = 'кبӹǹ١ͧ';
$string['diff'] = 'ᵡҧ';
$string['differences'] = 'ᵡҧҧѹ  $a->new_ver   $a->old_ver   ͧ $a->pagename.';
$string['disablecamel'] = 'Դҹ ԧ CamelCase';
$string['disabledpage'] = '˹ҹѧԡä';
$string['doesnotexist'] = 'ѧաҧ˹ҹ سҤԡ䢶ҡسͧ';
$string['downloadaszip'] = 'ѧպѴöӡôǹŴ';
$string['downloadtimes'] = 'ǹŴ $a ';
$string['dwnlnofiles'] = 'ѧ辺ѾŴ';
$string['dwnlsection'] = 'ǹѺǹŴ';
$string['editform1'] = 'ͧʹٻẺͧѹҡѡ öѧ';
$string['editform2'] = '¹ѧ˹¹ФҢ¹ءҧաúѹ֡';
$string['editthispage'] = '˹ҹ';
$string['emptypage'] = '˹';
$string['errorbinandtxt'] = 'բͼԴҴ: ˹ҹ㹻 BIN  TXT';
$string['errorhtml'] = '˹ҹ㹻 HTML';
$string['errornotype'] = 'բͼԴҴ    BIN  TXT';
$string['errororreason'] = 'բͼԴҴ˵ؼ';
$string['errorroandwr'] = 'բͼԴҴ ˹ҹöҹҹ';
$string['errorsize'] = '˹ҹբҴ˭ 64k';
$string['errversionsave'] = '¤ ҧس˹ҹդ蹷ӡúѹ֡ѹͧس سҡѺ˹ҷͷӡúѹ֡觷سӡ¹ŧŧ㹤ҡŴ˹ҹáͤŧ';
$string['ewikiacceptbinary'] = '͹حҵ亹';
$string['ewikiprinttitle'] = ' Wiki 㹷ء˹';
$string['export'] = '͡';
$string['exportformats'] = 'ٻẺ͡';
$string['exportsuccessful'] = '͡';
$string['exportto'] = '͡ѧ';
$string['fetchback'] = 'ӡѺ׹';
$string['file'] = '';
$string['filedownload'] = 'ǹŴ';
$string['fileisoftype'] = '繻';
$string['filtername'] = 'ԧ˹ Wiki ѵѵ';
$string['flagbin'] = 'BIN';
$string['flaghtm'] = 'HTM';
$string['flagoff'] = 'OFF';
$string['flagro'] = 'RO';
$string['flags'] = 'Flags';
$string['flagsset'] = '¹Է';
$string['flagtxt'] = 'TXT';
$string['flagwr'] = 'WR';
$string['for'] = 'Ѻ';
$string['forbidden'] = 'سö˹ҹ';
$string['groups'] = '';
$string['hits'] = '$a  ';
$string['howtooperate'] = 'Ըաҹ';
$string['howtowiki'] = 'Ըաҹ wiki';
$string['html'] = 'ٻẺ HTML';
$string['htmlmode'] = ' html';
$string['htmlonly'] = 'html ҹ';
$string['index'] = 'Ѫ';
$string['infoaboutpage'] = 'ǡѺ˹ҹ';
$string['initialcontent'] = '͡˹á';
$string['invalidroot'] = 'سѺ͹حҵѧ˹شЩй ֧öҧѧ䫵';
$string['lastchanged'] = '¹ŧش $a ';
$string['lastmodified'] = 'ش';
$string['linkdead'] = '';
$string['linkok'] = '';
$string['linkschecked'] = 'Ǩͺԧ';
$string['listall'] = '¡÷';
$string['listcandidates'] = 'List candidates';
$string['meta'] = 'Ѻ׺';
$string['moduledirectory'] = 'á';
$string['modulename'] = 'Wiki';
$string['modulenameplural'] = 'Wiki';
$string['mostoftenchangedpages'] = '˹ҷ¹ŧ·ش';
$string['mostvisitedpages'] = '˹ҷռҪҡش';
$string['newestpages'] = '˹ش';
$string['noadministrationaction'] = 'ѧաèѴ  Ѻк';
$string['nocandidatestoremove'] = 'ѧ˹ҷͧź ͡ \'$a\'  ʴء˹ ';
$string['nochangestorevert'] = 'ա¹ŧѺ';
$string['nohtml'] = ' html';
$string['nolinksfound'] = '辺ԧ˹ҹ';
$string['noregexp'] = 'ҹͧ繤ҵµ ö *  regex Ҩռʧҡ͡ǹк кت port  port number Фҹ鹷ء駷աҼҹҧ http';
$string['notadministratewiki'] = 'سöѴ wiki ';
$string['nothingtostrip'] = '˹ҷҡ˹';
$string['nowikicreated'] = 'բŷҧѺ wiki ';
$string['of'] = 'ͧ';
$string['offline'] = 'ͿŹ';
$string['optional'] = '͡';
$string['orphanedpage'] = '˹';
$string['orphanedpages'] = '˹';
$string['otherwikis'] = 'Wiki ';
$string['ownerunknown'] = 'Һ';
$string['pageactions'] = '觷ͧ÷˹ҹ';
$string['pageindex'] = 'Ѫ';
$string['pageinfo'] = 'Ţͧ˹';
$string['pagename'] = '˹';
$string['pagenamechoice'] = '';
$string['pageslinkingto'] = '˹ҷͧԧѧ˹ҹ';
$string['pagesremoved'] = 'ź˹';
$string['pagesreverted'] = '¹Ѻ';
$string['pagesstripped'] = 'ź˹ҹ';
$string['plaintext'] = '˹ѧ͸';
$string['preview'] = 'ٵҧ';
$string['readonly'] = '˹ҹҹҧ ';
$string['refs'] = 'ҧԧ';
$string['removenotice'] = '˵  ˹ҷաҧԧʴ˹ҹ  ewiki ͧͷբͨӡѴöͺ˹ҹ 㹡óշس˹  ˹ ˹Ҵѧǡաʴ蹡ѹ';
$string['removepagecheck'] = '㨹Фҵͧź˹Ҵѧ';
$string['removepages'] = 'ź˹';
$string['removeselectedpages'] = 'ź˹ҷ͡';
$string['revertallsince'] = '¹Ѻź¹ŧѧҡѹ';
$string['revertchanges'] = '¹Ѻ';
$string['revertlastonly'] = '¹Ѻҡ繡¹ش';
$string['revertpages'] = '¹Ѻ˹Ҿѹ';
$string['revertpagescheck'] = '㨹Фҵͧ¹˹ҵ仹Ѻѹ';
$string['revertthe'] = '¹Ѻź੾˹ҷջѭ';
$string['safehtml'] = 'Safe HTML';
$string['save'] = 'ѹ֡';
$string['searchwiki'] = ' Wiki';
$string['setpageflags'] = '駤ʶҹТͧ˹';
$string['sitemap'] = 'ѧ䫵';
$string['smfor'] = 'ѧ䫵Ѻ';
$string['status'] = 'ʶҹ';
$string['strippagecheck'] = 'Ҥзͧźѹ͡ҡ˹ҹ';
$string['strippages'] = 'źѹ';
$string['studentadminoptions'] = 'ԷԡèѴ wiki Ѻѡ¹';
$string['submit'] = '';
$string['tabattachments'] = 'Ṻ';
$string['tabedit'] = '';
$string['tabinfo'] = 'ѵԷ·';
$string['tablinks'] = 'ԧ';
$string['tabview'] = 'ʴ';
$string['thanksforcontribution'] = 'ͺسѺŷسҤ';
$string['thispageisntlinkedfromanywhereelse'] = 'ԧ˹ҹҨҡ';
$string['updatedpages'] = '˹ҷա';
$string['uplerror'] = '¤ջѭҧѾŴ';
$string['uplinsect'] = 'ѾŴѧ';
$string['uplnewnam'] = 'ѹ֡㹪';
$string['upload0'] = '㹡ѾŴŧ wiki';
$string['uploadedon'] = 'ѾŴ';
$string['uploadpicturebutton'] = 'ѾŴ';
$string['uplok'] = 'ѾŴ١ͧ';
$string['version'] = '';
$string['versionrangetoobig'] = 'سöźء͡ҡ˹ҹ  ѹش';
$string['versions'] = 'ѹ';
$string['versionstodelete'] = 'ѹͧź';
$string['viewpage'] = 'ӹǹ˹ҷҪ';
$string['viewsmfor'] = 'Ἱѧ䫵';
$string['wantedpages'] = '˹ҷͧ';
$string['wikidefaultpagename'] = 'Ѫ Wiki';
$string['wikiexport'] = '͡˹ҹ';
$string['wikiexportcomment'] = 'سöӡõ駤ͧ͡ҡ˹ҹ';
$string['wikilinkoptions'] = 'ͧ͡ Wiki ԧѵѵ';
$string['wikilinks'] = 'ԧ Wiki';
$string['wikiname'] = '˹';
$string['wikistartederror'] = 'բ Wiki    ö¹ŧ';
$string['wikitype'] = '';
$string['wikiusage'] = ' wiki';
$string['withbinaries'] = '亹';
$string['withvirtualpages'] = 'ԧ wiki';
$string['wrongversionrange'] = '$a  㹪ǧ١ͧ';

?>
